@@ -337,8 +337,7 @@ void gok_page_actions_toggle_type_valuator (gboolean Pressed)
 
 	if (Pressed == TRUE)
 	{
-	  /* update the action from the controls */
-	  m_pActionCurrent->Type = ACTION_TYPE_DWELL;
+		/* TODO: consider disabling some controls here */
 	}	
 	pSpinButton = (GtkSpinButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
 			"pointer_delay_spinbutton");
